<?php

namespace CreoCode\ContaoFormSubmissions\Classes;
use Contao\DataContainer;
use Contao\Database;

use CreoCode\ContaoFormSubmissions\Model\FormSubmissionsModel;
use CreoCode\ContaoFormSubmissions\Model\FormSubmissionsSetModel;
use CreoCode\ContaoFormSubmissions\Model\FormSubmissionsDataModel;


/**
 * Class FormSubmissions
 */
class FormSubmissions extends \Frontend {

    /**
     * Save form submission
     */
    public function saveSubmission($arrSubmitted, $arrLabels, $arrFields) {

        // check if option is activated
        if (empty($arrLabels['cc_save_submissions'])) {
            return;
        }

        // create new set if none found
        $set = FormSubmissionsSetModel::findOneBy('form_id', $arrLabels['id']);
        if (empty($set)) {
            // form not found, create a new set
            $set = new FormSubmissionsSetModel();
            $set->form_id = $arrLabels['id'];
            $set->form_alias = $arrLabels['alias'];
            $set->form_title = $arrLabels['title'];

            $set->tstamp = time();
            $set->save();
        }

        // Save Form
        $item = new FormSubmissionsModel();

        $item->pid = $set->current()->id;
        $item->tstamp = time();
        $item->recipient = $arrLabels['recipient'];

        $item->save();

        // Save Form Data
        $itemData = new FormSubmissionsDataModel();

        // prepare field names allowed in this form
        // hacky solution to filter out the session form values 
        // from previously submitted forms and service fileds, hashes, tokens etc
        $objFormFields = \FormFieldModel::findBy('pid', $arrLabels['id']);
        $arrFormFields = $objFormFields->fetchEach('name');

        $strData = '<ul>';
        // format form data
        foreach ($arrSubmitted as $key => $value) {
            if (array_search($key, $arrFormFields)) {
                // handle optional values if they are empty
                if (empty($value)) {
                    $value = '-';
                }
                // convert array values to comma separated strings
                if (is_array($value)) {
                    $value = implode(', ', $value);                    
                }
                $strData .= '<li><strong>' . htmlspecialchars($key) . '</strong>: ' . htmlspecialchars($value) . '</li>';
            }
        }
        $strData .= '</ul>';

        $itemData->pid = $item->id;
        $itemData->form_id = $arrLabels['id'];
        $itemData->tstamp = time();
        $itemData->subject = $arrLabels['subject'];
        $itemData->data = $strData;

        // save serialized data to database
        $itemData->arrSubmitted = serialize($arrSubmitted);
        $itemData->arrLabels = serialize($arrLabels);
        $itemData->arrFields = serialize($arrFields);

        $itemData->save();
        
    }

}
